Attribute class

Constructors

Attribute({required String name, String? type, String? init, String? html, bool isBool = false})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
html → String
final
init → String
final
isBool → bool
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited